<?php
require_once 'auth.php';
requireLogin();

$user = currentUser();
$groupId = (int)($user['group_id'] ?? 0);
if ($groupId < 9) {
    die("Unauthorized");
}

require_once '../config/db.php';

ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);


// ─────────────────────────────────────
// Setup Pagination and Search
// ─────────────────────────────────────
$limit = 20;
$page = max(1, (int)($_GET['page'] ?? 1));
$offset = ($page - 1) * $limit;
$search = trim($_GET['search'] ?? '');

$where = "eb.is_deleted = 0";
$params = [];
$types = "";

if ($search !== '') {
    $where .= " AND (e.name LIKE ? OR eb.label LIKE ? OR v.name LIKE ?)";
    $like = '%' . $search . '%';
    $params = [$like, $like, $like];
    $types = "sss";
}

// ─────────────────────────────────────
// Total Count
// ─────────────────────────────────────
$count_sql = "
    SELECT COUNT(*) FROM event_bookings eb
    LEFT JOIN events e ON eb.event_id = e.id
    LEFT JOIN venues v ON eb.venue_id = v.id
    WHERE $where
";
$count_stmt = $db->prepare($count_sql);
if (!empty($params)) {
    $count_stmt->bind_param($types, ...$params);
}
$count_stmt->execute();
$count_result = $count_stmt->get_result();
$total = (int)($count_result->fetch_row()[0] ?? 0);
$totalPages = max(1, ceil($total / $limit));

// ─────────────────────────────────────
// Main Query
// ─────────────────────────────────────
$sql = "
    SELECT eb.*, 
           e.name AS event_name,
           e.image_path AS event_default_image, 
           c.name AS country_name, 
           v.name AS venue_name 
    FROM event_bookings eb
    LEFT JOIN events e ON eb.event_id = e.id
    LEFT JOIN countries c ON eb.country_id = c.id
    LEFT JOIN venues v ON eb.venue_id = v.id
    WHERE $where
    ORDER BY FIELD(eb.booking_status, 'On Hold', 'Pre-Booking', 'Booking', 'Public'), eb.air_date DESC
    LIMIT ? OFFSET ?
";
$stmt = $db->prepare($sql);

if (!empty($params)) {
    $p1 = $params[0];
    $p2 = $params[1];
    $p3 = $params[2];
    $stmt->bind_param("sssii", $p1, $p2, $p3, $limit, $offset);
} else {
    $stmt->bind_param("ii", $limit, $offset);
}

$stmt->execute();
$result = $stmt->get_result();
?>

<!DOCTYPE html>
<html>
<head>
    <title>Booking Manager</title>
    <link rel="stylesheet" href="css/admin.css">
    <style>
        .event-type-badge {
            display: inline-block;
            background: #eee;
            color: #555;
            padding: 2px 6px;
            font-size: 11px;
            margin-top: 4px;
            border-radius: 4px;
        }
        .pagination {
            margin-top: 20px;
            text-align: center;
        }
        .pagination a {
            display: inline-block;
            padding: 6px 10px;
            margin: 0 3px;
            background: #444;
            color: #fff;
            text-decoration: none;
            border-radius: 4px;
        }
        .pagination .current {
            background: #9b1c1c;
            font-weight: bold;
        }
        .search-form {
            margin-bottom: 15px;
 text-align: right;
        }
        .search-form input[type="text"] {
            padding: 6px;
            width: 300px;
        }
        .search-form button {
            padding: 6px 10px;
        }
    </style>
</head>
<body>
<div class="dashboard-wrapper">
    <h2>Booking Manager</h2>
    <a class="button" href="add_booking.php">Add New Booking</a>

    <p><form class="search-form" method="get" action="">
        <input type="text" name="search" placeholder="Search event, label, or venue..." value="<?= htmlspecialchars($search ?? '') ?>">
        <button type="submit">Search</button>
    </form></p>

    <table class="table table-bordered">
        <thead>
        <tr>
            <th>Event Name</th>
            <th>Label</th>
            <th>Air Date</th>
            <th>Promo Deadline</th>
            <th>Booking Status</th>
            <th>Card</th>
            <th>Country</th>
            <th>Venue</th>
            <th>Image</th>
            <th>Actions</th>
        </tr>
        </thead>
        <tbody>
        <?php while ($booking = $result->fetch_assoc()): ?>
            <tr>
                <td>
                    <b><?= htmlspecialchars($booking['event_name'] ?? 'N/A') ?></b>
                    <div class="event-type-badge"><i><?= htmlspecialchars($booking['event_type'] ?? '') ?></i></div>
                </td>
                <td><?= htmlspecialchars($booking['label'] ?? '') ?></td>
                <td><?= htmlspecialchars($booking['air_date'] ?? '') ?></td>
                <td><?= htmlspecialchars($booking['promo_deadline'] ?? '') ?></td>
                <?php
                    $status = htmlspecialchars($booking['booking_status'] ?? '');
                    $badgeClass = match ($status) {
                        'Public' => 'status-public',
                        'Booking' => 'status-booking',
                        default => 'status-default'
                    };
                ?>
                <td><span class="<?= $badgeClass ?>"><?= $status ?></span></td>

                <td><a href="manage_card.php?booking_id=<?= (int)$booking['id'] ?>" class="button small">Card</a></td>
                <td><?= htmlspecialchars($booking['country_name'] ?? '') ?></td>
                <td><?= htmlspecialchars($booking['venue_name'] ?? '') ?></td>
                <td>
                    <?php
                    $img_src = '';
                    if (!empty($booking['custom_image_path'])) {
                        $img_src = "../../uploads/event-images/" . htmlspecialchars($booking['custom_image_path']);
                    } elseif (!empty($booking['event_default_image'])) {
                        $img_src = "../../uploads/show-logos/" . htmlspecialchars($booking['event_default_image']);
                    }
                    if ($img_src):
                    ?>
                        <img src="<?= $img_src ?>" style="max-height: 60px; max-width: 100px; object-fit: contain;" alt="Show Image">
                    <?php endif; ?>
                </td>
                <td><a class="button small" href="edit_booking.php?id=<?= (int)$booking['id'] ?>">Edit</a></td>
            </tr>
        <?php endwhile; ?>
        </tbody>
    </table>

    <?php if ($totalPages > 1): ?>
    <div class="pagination">
        <?php for ($p = 1; $p <= $totalPages; $p++): ?>
            <?php if ($p == $page): ?>
                <span class="current"><?= $p ?></span>
            <?php else: ?>
                <a href="?page=<?= $p ?>&search=<?= urlencode($search) ?>"><?= $p ?></a>
            <?php endif; ?>
        <?php endfor; ?>
    </div>
    <?php endif; ?>
</div>
</body>
</html>
