<?php
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

require_once '../config/db.php';
require_once 'auth.php';
require_once 'libs/site-settings-lib.php';
requireLogin();
if (!hasGroupPermission(10)) die("Unauthorized");

$fields = [
'license_key',
    'dashboard_logo_url',
    'dashboard_favicon_url',
    'site_url',
    'promotion_name',
    'promotion_shortname',
    'promotion_initials',
    'promotion_id',
   
    'allow_php_editing',
    'promotion_timezone',
     'openai_admin_api_key',
'discord_news_webhook_url',

// new mail settings:
  'mail_method',            // 'mail' or 'smtp'
  'smtp_host',
  'smtp_port',
  'smtp_encryption',        // e.g. 'ssl', 'tls' or blank
  'smtp_username',
  'smtp_password',
  'email_from_address',
  'email_from_name'
];
$userId       = currentUser()['id'];
$auditChanges = [];

// ───────────────────────────────────────────────────────────────────────────
// SINGLE POST HANDLER
// ───────────────────────────────────────────────────────────────────────────
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // 1) Validate the license key first
    $licenseKey  = trim($_POST['license_key'] ?? '');
    // right before you call file_get_contents():
$localVersion = getSetting('ems_local_version') ?? '0';   // or however you store it
$validateUrl  = 'https://dashboard.efedmanagementsuite.com/download_dashboard/api/validate_license.php'
              . '?key='     . urlencode($licenseKey)
              . '&version=' . urlencode($localVersion);


    $resp = @file_get_contents($validateUrl);
    if ($resp === false) {
        $error = 'Could not validate license key. Please try again later.';
    } else {
        $payload = json_decode($resp, true);
        if (empty($payload['valid'])) {
            $error = 'That license key is not valid.';
        }
    }

    // 2) If validation failed, show error and stop here
    if (isset($error)) {
        echo "<div class='notice error'>{$error}</div>";
        // you might want to include the rest of the form here so the user can retry
        exit;
    }

    // 3) License is good — save **all** settings
    foreach ($fields as $key) {
        $value = isset($_POST[$key]) ? trim($_POST[$key]) : '';
        if ($key === 'allow_php_editing') {
            $value = isset($_POST[$key]) ? '1' : '0';
        }
        $oldValue = getSetting($key);
        if ($oldValue !== $value) {
            setSetting($key, $value);
            $auditChanges[] = "Updated {$key}: '{$oldValue}' → '{$value}'";
        }
    }

    // 4) Audit log
    if (!empty($auditChanges)) {
        $notes = implode("\\n", array_map('trim', $auditChanges));
        $stmt  = $db->prepare("
            INSERT INTO audit_logs 
              (user_id, action_type, target_type, target_name, notes)
            VALUES (?, 'update', 'site_setting', 'settings_website', ?)
        ");
        $stmt->bind_param("is", $userId, $notes);
        $stmt->execute();
    }

    // 5) Redirect to avoid resubmission
    header("Location: settings_website.php?updated=1");
    exit;
}
// ───────────────────────────────────────────────────────────────────────────

?>
<!DOCTYPE html>
<html>
<head>
    <title>Website Settings</title>
    <link rel="stylesheet" href="css/admin.css">
</head>
<body>
  <div class="dashboard-wrapper">
    <h2>Website Settings</h2>
    <?php if (isset($_GET['updated'])): ?>
      <div class="notice success">Settings updated.</div>
    <?php endif; ?>

    <form method="POST">

  <label for="license_key">License Key</label><br>
  <input
    type="text"
    id="license_key"
    name="license_key"
    class="form-control"
    required
    value="<?= htmlspecialchars(getSetting('license_key') ?? '') ?>"
  /><br><br>



    <label>Logo URL:</label><br>
    <input type="text" name="dashboard_logo_url" value="<?= getSetting('dashboard_logo_url') ?>"><br><br>

    <label>Favicon URL:</label><br>
    <input type="text" name="dashboard_favicon_url" value="<?= getSetting('dashboard_favicon_url') ?>"><br><br>

    <label>Main Website URL:</label><br>
    <input type="text" name="site_url" value="<?= getSetting('site_url') ?>"><br><br>

    <label>Promotion Name:</label><br>
    <input type="text" name="promotion_name" value="<?= getSetting('promotion_name') ?>"><br><br>

    <label>Promotion Shortname:</label><br>
    <input type="text" name="promotion_shortname" value="<?= getSetting('promotion_shortname') ?>"><br><br>

    <label>Promotion Initials:</label><br>
    <input type="text" name="promotion_initials" value="<?= getSetting('promotion_initials') ?>"><br><br>

    <label>Promotion ID:</label><br>
    <input type="text" name="promotion_id" value="<?= getSetting('promotion_id') ?>"><br><br>

    <label>Promotion Timezone:</label><br>
<select name="promotion_timezone">
<?php
$timezones = DateTimeZone::listIdentifiers();
$currentTz = getSetting('promotion_timezone') ?: 'UTC';
foreach ($timezones as $tz) {
    $selected = $tz === $currentTz ? 'selected' : '';
    echo "<option value=\"$tz\" $selected>$tz</option>";
}
?>
</select><br><br>

<label>Global Admin Open AI Key</label>
<input type="text" name="openai_admin_api_key" value="<?= htmlspecialchars(getSetting('openai_admin_api_key') ?? '') ?>" style="width: 100%;">
<BR><BR>

 <label for="discord_news_webhook_url">Discord News Webhook URL:</label><br>
    <input
      type="url"
      id="discord_news_webhook_url"
      name="discord_news_webhook_url"
      value="<?= htmlspecialchars(getSetting('discord_news_webhook_url') ?: '', ENT_QUOTES) ?>"
      style="width:100%;"
      placeholder="https://discord.com/api/webhooks/…"
    ><br><br>

<h3>Mail Settings</h3>

<label>Method:</label><br>
<select name="mail_method">
  <option value="mail" <?= getSetting('mail_method')==='mail' ? 'selected' : '' ?>>PHP mail()</option>
  <option value="smtp" <?= getSetting('mail_method')==='smtp' ? 'selected' : '' ?>>SMTP</option>
</select><br><br>

<label>SMTP Host:</label><br>
<input type="text" name="smtp_host"
  value="<?= htmlspecialchars(getSetting('smtp_host') ?: '', ENT_QUOTES) ?>"
  placeholder="smtp.example.com"><br><br>

<label>SMTP Port:</label><br>
<input type="text" name="smtp_port"
  value="<?= htmlspecialchars(getSetting('smtp_port') ?: '', ENT_QUOTES) ?>"
  placeholder="587"><br><br>

<label>Encryption:</label><br>
<input type="text" name="smtp_encryption"
  value="<?= htmlspecialchars(getSetting('smtp_encryption') ?: '', ENT_QUOTES) ?>"
  placeholder="tls (or ssl)"><br><br>

<label>SMTP Username:</label><br>
<input type="text" name="smtp_username"
  value="<?= htmlspecialchars(getSetting('smtp_username') ?: '', ENT_QUOTES) ?>"><br><br>

<label>SMTP Password:</label><br>
<input type="password" name="smtp_password"
  value="<?= htmlspecialchars(getSetting('smtp_password') ?: '', ENT_QUOTES) ?>"><br><br>

<label>“From” Email Address:</label><br>
<input type="email" name="email_from_address"
  value="<?= htmlspecialchars(getSetting('email_from_address') ?: '', ENT_QUOTES) ?>"
  placeholder="no-reply@yourdomain.com"><br><br>

<label>“From” Name:</label><br>
<input type="text" name="email_from_name"
  value="<?= htmlspecialchars(getSetting('email_from_name') ?: '', ENT_QUOTES) ?>"
  placeholder="Your Site Name"><br><br>




    <label><input type="checkbox" name="allow_php_editing" value="1" <?= getSetting('allow_php_editing') == '1' ? 'checked' : '' ?>> Allow PHP Editing for Content Pages</label><br><br>

    <button type="submit">Save Settings</button>
</form>
</div>
</body>
</html>