<?php
require_once __DIR__ . '/../config/db.php';
require_once __DIR__ . '/../admin/auth.php';

$page  = isset($_GET['p']) ? max(1, (int)$_GET['p']) : 1;
$limit = 25;
$offset = ($page - 1) * $limit;

$entries = [];
$whereClauses = [];
$params = [];
$types = '';

function bindParams(&$stmt, $types, &$params) {
    if (!empty($types)) {
        $stmt->bind_param($types, ...$params);
    }
}

// Build queries
$unionQueries = [];

$query = "
    SELECT 
        'news' AS source,
        n.id AS news_id,
        n.title,
        n.slug,
        nc.name AS category,
        n.created_at AS posted_date,
        c.name AS character_name,
        NULL AS event_id,
        NULL AS event_label,
        NULL AS event_title
    FROM news n
    JOIN news_categories nc ON n.category = nc.id
    LEFT JOIN characters c ON n.character_id = c.id
    WHERE nc.show_in_chronology = 1
";
$unionQueries[] = $query;

$query = "
    SELECT 
        'promo' AS source,
        NULL AS news_id,
        p.title,
        p.slug,
        'Promo' AS category,
        p.post_date AS posted_date,
        c.name AS character_name,
        NULL AS event_id,
        NULL AS event_label,
        NULL AS event_title
    FROM promos p
    LEFT JOIN characters c ON p.character_id = c.id
    WHERE p.is_draft = 0
";
$unionQueries[] = $query;

$query = "
    SELECT 
        'event' AS source,
        NULL AS news_id,
        e.name AS title,
        NULL AS slug,
        'Event' AS category,
        eb.air_date AS posted_date,
        NULL AS character_name,
        e.id AS event_id,
        eb.label AS event_label,
        e.name AS event_title
    FROM event_bookings eb
    JOIN events e ON eb.event_id = e.id
    WHERE eb.is_deleted = 0 AND eb.booking_status = 'Public'
";
$unionQueries[] = $query;

$sql = implode("\nUNION ALL\n", $unionQueries) . " ORDER BY posted_date DESC LIMIT ? OFFSET ?";
$params[] = $limit;
$params[] = $offset;
$types .= 'ii';

$stmt = $db->prepare($sql);
bindParams($stmt, $types, $params);
$stmt->execute();
$result = $stmt->get_result();

while ($row = $result->fetch_assoc()) {
    $entries[] = $row;
}

function buildChronologyUrl($page = 1) {
    return "/chronology" . ($page > 1 ? "/page/" . (int)$page : "");
}
?>

<div class="site-content">
    <div class="content-box">
        <h2 class="chronology-title">CHRONOLOGY</h2>

        <?php if (!empty($entries)): ?>
            <table class="chronology-table">
                <thead>
                    <tr>
                        <th style="width:75%">Entry</th>
                        <th>Date</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($entries as $entry): ?>
                        <tr>
                            <td>
                                <?php if ($entry['source'] === 'promo'): ?>
                                    <a href="/promo/<?= urlencode($entry['slug']) ?>">
                                        [<?= strtoupper($entry['category']) ?>] <?= htmlspecialchars($entry['title']) ?> by <?= htmlspecialchars($entry['character_name'] ?? 'Unknown') ?>
                                    </a>
                                <?php elseif ($entry['source'] === 'news'): ?>
                                    <a href="/news/<?= urlencode($entry['slug']) ?>">
                                        [<?= strtoupper($entry['category']) ?>] <?= htmlspecialchars($entry['title']) ?> by <?= htmlspecialchars($entry['character_name'] ?? 'Unknown') ?>
                                    </a>
                                <?php elseif ($entry['source'] === 'event'): ?>
                                    <a href="/event/<?= $entry['event_id'] ?>">
                                        [Event] <?= htmlspecialchars($entry['event_title']) ?> (<?= htmlspecialchars($entry['event_label']) ?>)
                                    </a>
                                <?php endif; ?>
                            </td>
                            <td><?= date('F j, Y', strtotime($entry['posted_date'])) ?></td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        <?php else: ?>
            <p>No chronology items found.</p>
        <?php endif; ?>

        <!-- Pagination -->
        <div class="pagination">
            <?php
            $countSql = "SELECT COUNT(*) FROM (" . implode("\nUNION ALL\n", $unionQueries) . ") AS total";

            $countStmt = $db->prepare($countSql);
            $countStmt->execute();
            $countResult = $countStmt->get_result();
            $totalRows = $countResult->fetch_row()[0] ?? 0;
            $totalPages = ceil($totalRows / $limit);

            if ($totalPages > 1):
                echo '<div class="pagination-links">';
                if ($page > 1) {
                    echo '<a href="' . buildChronologyUrl(1) . '">&laquo; First</a> ';
                    echo '<a href="' . buildChronologyUrl($page - 1) . '">Prev</a> ';
                }

                for ($i = 1; $i <= $totalPages; $i++) {
                    if ($i == $page) {
                        echo "<strong>$i</strong> ";
                    } else {
                        echo '<a href="' . buildChronologyUrl($i) . '">' . $i . '</a> ';
                    }
                }

                if ($page < $totalPages) {
                    echo '<a href="' . buildChronologyUrl($page + 1) . '">Next</a> ';
                    echo '<a href="' . buildChronologyUrl($totalPages) . '">Last &raquo;</a>';
                }
                echo '</div>';
            endif;
            ?>
        </div>
    </div>
</div>
