<?php
// user_content/public_event.php
// ----------------------------------------------------------------------------
// Only “numeric ID” mode.  Expects /event/123 → $_GET['id'] = 123
// ----------------------------------------------------------------------------
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// 1) Bootstrap & DB connection
require_once __DIR__ . '/../config/db.php';

// 2) Grab the booking_id from GET
$booking_id = isset($_GET['id']) && ctype_digit($_GET['id'])
    ? intval($_GET['id'])
    : 0;

if ($booking_id <= 0) {
    echo "<h2>No event specified.</h2>";
    exit;
}

// 3) Fetch that booking (only if it’s “Public” and not deleted)
//    Notice we now also SELECT eb.label AS booking_label
$sql = "
  SELECT
    eb.id                AS booking_id,
    eb.label             AS booking_label,
    eb.air_date          AS air_date,
    eb.custom_image_path AS booking_image,
    eb.booking_status    AS booking_status,
    e.id                 AS event_id,
    e.name               AS event_name,
    e.image_path         AS event_image,
    v.id                 AS venue_id,
    v.name               AS venue_name,
    v.location           AS venue_location
  FROM event_bookings eb
  INNER JOIN events e
    ON eb.event_id = e.id
  LEFT JOIN venues v
    ON eb.venue_id = v.id
  WHERE
    eb.id = ?
    AND eb.is_deleted = 0
    AND eb.booking_status = 'Public'
  LIMIT 1
";

$stmt = $db->prepare($sql);
$stmt->bind_param('i', $booking_id);
$stmt->execute();
$res = $stmt->get_result();

if ($res->num_rows === 0) {
    // Not found, or not “Public”
    echo "<h2>Event not found or not yet public.</h2>";
    exit;
}

$booking = $res->fetch_assoc();
$stmt->close();

// 4) Choose image (booking‐level vs. event‐level)

$imageFilename = trim($booking['booking_image'] ?? '') !== ''
    ? $booking['booking_image']
    : $booking['event_image'];


// Adjust this path to wherever you store show logos:
$imageURL = '../uploads/show-logos/' . $imageFilename;
?>

<div class="site-content">
  <div class="content-box">

    <!-- 5) Header: image + meta -->
    <div class="event-header">
      <center>
        <?php if ($imageFilename): ?>
          <img src="<?= htmlspecialchars($imageURL) ?>"
               alt="<?= htmlspecialchars($booking['event_name']) ?> Image">
        <?php endif; ?>
      </center>

      <center>
        <div class="event-meta">
          <!--
            Display the event name, then the booking label right after it.
            For example: “My Big Show – Episode 5”
          -->
          <strong>
            <?= htmlspecialchars($booking['event_name']) ?>:
            <?php if (strlen($booking['booking_label'] ?? '') > 0): ?><?= htmlspecialchars($booking['booking_label']) ?>
            <?php endif; ?>
          </strong>
          <br>
          <i>
            <?= date('F j, Y', strtotime($booking['air_date'])) ?>
            <?php if ($booking['venue_name']): ?>
              | <?= htmlspecialchars($booking['venue_name']) ?>
              <?= $booking['venue_location']
                   ? " - " . htmlspecialchars($booking['venue_location'])
                   : '' ?>
            <?php endif; ?>
          </i>
        </div>
      </center>
    </div>

    <hr>
<br>
    <?php
    // 6) Fetch matches & segments for booking_id
    $sql2 = "
      SELECT
        m.id                    AS match_id,
        m.match_name            AS title,
        m.match_content         AS content,
        m.is_segment            AS is_segment,
        m.reserved_segment_id   AS reserved_segment_id
      FROM event_matches m
      WHERE m.booking_id = ?
      ORDER BY m.sort_order ASC
    ";
    $stmt2 = $db->prepare($sql2);
    $stmt2->bind_param('i', $booking_id);
    $stmt2->execute();
    $res2 = $stmt2->get_result();

    // Collect credits for later
    $credits = [];

    while ($row = $res2->fetch_assoc()) {
        $isSegment = (bool) $row['is_segment'];
        $title     = $row['title'];
        $content   = $row['content']; // assumed safe HTML
        ?>

        <div class="match-segment">
          <p class="uppercase"><center><h3><?= htmlspecialchars($title) ?></h3></center></p>
          <div class="content">
            <?= $content /* raw HTML from match_preview */ ?>
          </div>
        </div>

        <?php
        // 6b) Lookup writers (match vs. segment)
        if ($isSegment) {
            $segId = intval($row['reserved_segment_id']);
            if ($segId) {
                $stmtC = $db->prepare("
                  SELECT u.username
                  FROM segment_credits sc
                  INNER JOIN users u ON sc.user_id = u.id
                  WHERE sc.segment_id = ?
                ");
                $stmtC->bind_param('i', $segId);
                $stmtC->execute();
                $rc = $stmtC->get_result();

                $writers = [];
                while ($u = $rc->fetch_assoc()) {
                    $writers[] = $u['username'];
                }
                $stmtC->close();

                if (count($writers) > 0) {
                    $credits[] = [
                        'type'    => 'Segment',
                        'title'   => $title,
                        'writers' => $writers
                    ];
                }
            }
        } else {
            $matchId = intval($row['match_id']);
            $stmtC = $db->prepare("
              SELECT u.username
              FROM event_match_writers emw
              INNER JOIN users u ON emw.user_id = u.id
              WHERE emw.match_id = ?
            ");
            $stmtC->bind_param('i', $matchId);
            $stmtC->execute();
            $rc = $stmtC->get_result();

            $writers = [];
            while ($u = $rc->fetch_assoc()) {
                $writers[] = $u['username'];
            }
            $stmtC->close();

            if (count($writers) > 0) {
                $credits[] = [
                    'type'    => 'Match',
                    'title'   => $title,
                    'writers' => $writers
                ];
            }
        }
    } // end while
    $stmt2->close();
    ?>

 

    <?php if (!empty($credits)): ?>
      <div class="credits-box">
        <h4>Show Credits</h4>
        <ul>
          <?php foreach ($credits as $c): ?>
            <li>
              <strong><?= ($c['type'] === 'Segment' ? 'Segment' : 'Match') ?>:</strong>
              “<?= htmlspecialchars($c['title']) ?>” –
              Written by <?= htmlspecialchars(implode(', ', $c['writers'])) ?>.
            </li>
          <?php endforeach; ?>
        </ul>
<BR>Results Compiled by the eFed Management Suite
      </div>
    <?php endif; ?>

  </div> <!-- /.content-box -->
</div> <!-- /.site-content -->
